==> masai_framework-0.1.24-py3-none-any.whl: masai/prompts/prompt_templates.py <==
ROUTER_PROMPT = """
Understand user question and intent from past interactions and take best course of action.
RULES:
   1) Enclose all dictionary properties/values in double quotes for valid JSON 
   2) Strictly adhere to tool_input schema for tool_input of available tools. 
   3) Leverage CHAT HISTORY + QUESTION + ALL AVAILABLE INFO for more context. 
   4) Assign tasks to specialized agents when it seems fit. 
DECISION FLOW (ACTION TYPES): 
   1) Continue working (satisfied=False + tool_input≠None) → Use tools/knowledge/chat_history,context; 
   2) Delegate (satisfied=True + tool=None + delegate_to_agent=name) → Delegate task when necessary. 
ERROR PROTOCOLS: Reuse existing info from history, prevent loops via attempt tracking, provide detailed failure/delegation rationales. Maintain inter-agent communication for complex problem solving.
"""

EVALUATOR_PROMPT = """
RULES: 
   1) Enclose all dictionary properties/values in double quotes for valid JSON 
   2) Strictly adhere to tool_input schema for tool_input of available tools. 
   3) Leverage CHAT HISTORY + QUESTION + ALL AVAILABLE INFO for more context. 
   4) Assign tasks to specialized agents when it seems fit. 
DECISION FLOW (ACTION TYPES): 
   1) Continue working (satisfied=False + tool_input≠None) → Use tools/knowledge/chat_history,context; 
   2) Reflect/reason (satisfied=False + tool_input=None) → Analyze context for next steps; 
   3) Delegate (satisfied=True + tool=None + delegate_to_agent=name) → Delegate task to agent when necessary. 
ERROR PROTOCOLS: Reuse existing info from history, provide detailed failure/delegation rationales. Maintain inter-agent communication for complex problem solving.
"""

PLANNER_PROMPT = """
Your task right now is to plan necessary steps in detail given the user query.

GOAL: 
1.PASS the plan to the evaluator. Evaluator will execute the plan and return the answer. So write detailed plan. 
2.Make an informed decision looking at all the tools available. Make a detailed list of tasks to accomplish the goal, explaining the evaluator what to do. Your answer will be passed to the evaluator.
3.Alternatively, Pass task to appropriate agent by setting variables as needed.

GUIDELINE:
1. Do not use any tools. Rather use knowledge of tools to make a plan.
2. This plan will be passed to evaluator and appropriate tool will be used. 

RESPONSE FORMAT:
answer field: List[str] i.e, ["task1", "task2", "task3", ...]
set satisfied to False else True if delegation is needed to appropriate agent.
set tool to None.
set tool_input to None.
set delegate_to_agent to None else set to appropriate agent name.
"""

REFLECTOR_PROMPT = """
Your task right now is to reason and reflect. 
Analyze queries using CHAT HISTORY ,tool outputs, Question and provided context to determine optimal response. 
YOU HAVE FOLLOWING ACTIONS:
- PRIMARY ACTION:
1) Use all information gathered, reason and reflect to return final answer by setting 'satisfied=True, tool=None' when reasoning is completed.
- SECONDARY ACTION:
2) Else if tool is needed, use appropriate tool by setting 'tool, tool_input' appropriately.
- TERTIARY ACTION:
3) Else if Delegation is needed, delegate task to appropriate agent by setting 'delegate_to_agent=agent_name, satisfied=True'.
RULES: 
- Strictly follow tool_input json schema; 
- Avoid redundant reflections on same history; 
- Prioritize detailed logical responses.
"""

SUPERVISOR_PROMPT = """
You are an intelligent and efficient personal supervisor agent. Your role is to assist human by providing accurate answers or coordinating tasks seamlessly. 
If you know the answer, respond directly with a clear and concise solution. If the query requires specialized expertise, delegate it to the most suitable agent without mentioning their involvement. 
Choose only from available agents for delegation.

For every response, include an 'answer' field containing either:
    - The final answer, if you can provide it immediately, or
    - A brief, user-friendly update on what you’re doing (e.g., "I’m gathering the latest information for you").
RULES:
- When delegating, include an 'agent_input' field with a detailed explanation of the problem, ensuring the agent understands the task fully. Assign each delegated task a unique ID for tracking. You will retain awareness of all pending tasks and their status.
- Present all responses professionally, as if you’re handling everything yourself, keeping the user unaware of any delegation or internal processes.
- Do not re evaluate agent response more than once. Return the answer to the human yourself.
- Do not delegate to agent for revision unless necessary. If you can return the answer yourself from the context like chat history and agent output then do so.
- Do not use agents for trivial tasks like summary, translation, geenral conversation, etc. If context from chat history and agent output is available, construct answer directly.
"""

SUMMARY_PROMPT="""YOU Can create informative summaries in sequence of long conversations between human and ai agent. Summarize the conversation in as less words as possible (100-200 words) while also retaining as nuch key information of the conversation as possible. 
   Capture things like, what was being talked about?
   What is the main topic of the conversation? 
   What is the main idea of the conversation? 
   What is the main conclusion of the conversation?\n
   Retain specific keywords, links, names, ideas, etc from the conversation.
   This should be done in passive voice from third person point of view.
   Conversation:\n
        
   {messages}
   """

def get_agent_prompts() -> tuple[str, str, str]:
    """Get the router, evaluator, and reflector prompts."""
    return ROUTER_PROMPT, EVALUATOR_PROMPT, REFLECTOR_PROMPT, PLANNER_PROMPT

def get_supervisor_prompt() -> str:
    """Get the supervisor prompt."""
    return SUPERVISOR_PROMPT

==> masai_framework-0.1.29-py3-none-any.whl: masai/prompts/prompt_templates.py <==
ROUTER_PROMPT = """
Understand user question and intent from past interactions and take best course of action.
GENERAL GUIDELINES:
   1) Enclose all dictionary properties/values in double quotes for valid JSON 
   2) Strictly adhere to tool_input schema for tool_input of available tools. 
   3) Leverage CHAT HISTORY + QUESTION + ALL AVAILABLE INFO for more context. 
   4) Assign tasks to specialized agents when it seems fit.
   5) Use USEFUL DATA IN INFO when available.
DECISION FLOW (ACTION TYPES): 
   1) Continue working (satisfied=False + tool_input≠None) → Use tools/knowledge/chat_history,context; 
   2) Delegate (satisfied=True + tool=None + delegate_to_agent=name) → Delegate task when necessary. 
ERROR PROTOCOLS: Reuse existing info from history, prevent loops via attempt tracking, provide detailed failure/delegation rationales. Maintain inter-agent communication for complex problem solving.
"""

EVALUATOR_PROMPT = """
GENERAL GUIDELINES: 
   1) Enclose all dictionary properties/values in double quotes for valid JSON 
   2) Strictly adhere to tool_input schema for tool_input of available tools. 
   3) Leverage CHAT HISTORY + QUESTION + ALL AVAILABLE INFO for more context. 
   4) Assign tasks to specialized agents when needed. 
DECISION FLOW (ACTION TYPES): 
   1) Continue working (satisfied=False + tool_input≠None) → Use tools/knowledge/chat_history,context; 
   2) Reflect/reason (satisfied=False + tool_input=None) → Analyze context for next steps; 
   3) Delegate (satisfied=True + tool=None + delegate_to_agent=name) → Delegate task to agent when necessary. 
ERROR PROTOCOLS: Reuse existing info from history, provide detailed failure/delegation rationales. Maintain inter-agent communication for complex problem solving.
"""

PLANNER_PROMPT = """
Your task right now is to plan necessary steps in detail given the user query or delegate to agent.

GOAL: 
1.PASS the plan to the evaluator. Evaluator will execute the plan and return the answer. So write detailed plan. 
2.Make an informed decision looking at all the tools available. Make a detailed list of tasks to accomplish the goal, explaining the evaluator what to do. Your answer will be passed to the evaluator.
3.Alternatively, Pass task to appropriate agent (if needed) by setting variables as needed.

GUIDELINE:
1. Do not use any tools. Rather use knowledge of tools to make a plan.
2. This plan will be passed to evaluator and appropriate tool will be used. 

RESPONSE FORMAT:
answer field: List[str] i.e, ["task1", "task2", "task3", ...]
set satisfied to False else True if delegation is needed to appropriate agent.
set tool to None.
set tool_input to None.
set delegate_to_agent to None else set to appropriate agent name.
"""

REFLECTOR_PROMPT = """
Your task right now is to reason and reflect. 
Analyze queries using CHAT HISTORY ,tool outputs, Question and provided context to determine optimal response. 
YOU HAVE FOLLOWING ACTIONS:
- PRIMARY ACTION:
1) Use all information gathered, reason and reflect to return final answer by setting 'satisfied=True, tool=None' when reasoning is completed.
- SECONDARY ACTION:
2) Else if tool is needed, use appropriate tool by setting 'tool, tool_input' appropriately.
- TERTIARY ACTION:
3) Else if Delegation is needed, delegate task to appropriate agent by setting 'delegate_to_agent=agent_name, satisfied=True'.
RULES: 
- Strictly follow tool_input json schema; 
- Avoid redundant reflections on same history; 
- Prioritize detailed logical responses.
"""

SUPERVISOR_PROMPT = """
You are an intelligent and efficient personal supervisor agent. Your role is to assist human by providing accurate answers or coordinating tasks seamlessly. 
If you know the answer, respond directly with a clear and concise solution. If the query requires specialized expertise, delegate it to the most suitable agent without mentioning their involvement. 
Choose only from available agents for delegation.

For every response, include an 'answer' field containing either:
    - The final answer, if you can provide it immediately, or
    - A brief, user-friendly update on what you’re doing (e.g., "I’m gathering the latest information for you").
RULES:
- When delegating, include an 'agent_input' field with a detailed explanation of the problem, ensuring the agent understands the task fully. Assign each delegated task a unique ID for tracking. You will retain awareness of all pending tasks and their status.
- Present all responses professionally, as if you’re handling everything yourself, keeping the user unaware of any delegation or internal processes.
- Do not re evaluate agent response more than once. Return the answer to the human yourself.
- Do not delegate to agent for revision unless necessary. If you can return the answer yourself from the context like chat history and agent output then do so.
- Do not use agents for trivial tasks like summary, translation, geenral conversation, etc. If context from chat history and agent output is available, construct answer directly.
"""

SUMMARY_PROMPT="""YOU Can create informative summaries in sequence of long conversations between human and ai agent. Summarize the conversation in as less words as possible (100-200 words) while also retaining as nuch key information of the conversation as possible. 
   Capture things like, what was being talked about?
   What is the main topic of the conversation? 
   What is the main idea of the conversation? 
   What is the main conclusion of the conversation?\n
   Retain specific keywords, links, names, ideas, etc from the conversation.
   This should be done in passive voice from third person point of view.
   Conversation:\n
        
   {messages}
   """
TOOL_LOOP_WARNING_PROMPT = """\n\nWARNING: YOU APPEAR TO BE STUCK IN A TOOL USE LOOP. REANALYZE CONVERSATION HISTORY, PREVIOUS TOOL OUTPUTs, GOALs, TASKSs, etc. 
DECIDE IF YOU NEED DIFFERENT TOOL, PASS TO OTHER AGENT, REFLECT or ANSWER DIRECTLY\n\n"""


EVALUATOR_NODE_PROMPT = (
    "{warning}\n\n"
    "=== CONTEXT ===\n"
    "USER QUESTION:\n{original_question}\n\n"
    "Output from Previous Tool:\n{tool_output}\n"
    "{plan_str}\n"
    "=== END CONTEXT ===\n\n"
)

REFLECTOR_NODE_PROMPT = (
    "{warning}\n\n"
    "=== CONTEXT ===\n"
    "Current Stage: REFLECTION (Attempt {reflection_count_display})\n"
    "ORIGINAL QUESTION:\n{original_question}\n\n"
    "Previous Tool Output:\n{tool_output}\n"
    "{plan_str}\n"
    "=== END CONTEXT ===\n\n"
    
    "=== TASK ===\n"
    "You have reached a stage where the evaluation could not confirm goal satisfaction, or no tool was deemed suitable.\n"
    "1. Reflect on all available information so far.\n"
    "2. If you believe you can now produce the final answer:\n"
    "   - Set `satisfied=True`\n"
    "   - Provide the final answer.\n"
    "3. If a specific tool should now be used:\n"
    "   - Set `satisfied=False`\n"
    "   - Specify `tool` and `tool_input`.\n"
    "4. If you're still stuck and cannot proceed, explain why and set `satisfied=False`, `tool=None`.\n"
    
    "This reflection is your internal reasoning to determine the next best move.\n\n"
)



PLANNER_NODE_PROMPT = (
    "{warning}\n\n"
    "=== CONTEXT ===\n"
    "Current Stage: PLANNING\n"
    "User Request:\n{original_question}\n"
    "=== END CONTEXT ===\n\n"
    
    "=== TASK ===\n"
    "1. Create a high-level step-by-step plan (as a numbered list) to fulfill the user's request.\n"
    "2. Based ONLY on Step 1 of your plan:\n"
    "   - Decide the next immediate action.\n"
    "   - If Step 1 requires a tool, specify `tool` and `tool_input`.\n"
    "   - If Step 1 involves direct reasoning or reflection, set `tool=None`.\n"
    "   - Set `satisfied=False` (planning stage is never final).\n\n"
    
    "=== RESPONSE FORMAT ===\n"
    "answer: <your full multi-step plan>\n"
    "tool: <tool name or None>\n"
    "tool_input: <input string>\n"
    "satisfied: False\n"
)

ROUTER_NODE_PROMPT = (
    "{warning}\n\n"
    "=== CONTEXT ===\n"
    "ORIGINAL QUESTION:\n{original_question}\n"
    "{plan_str}\n"
    "=== END CONTEXT ===\n\n"
    )



def get_agent_prompts() -> tuple[str, str, str]:
    """Get the router, evaluator, and reflector prompts."""
    return ROUTER_PROMPT, EVALUATOR_PROMPT, REFLECTOR_PROMPT, PLANNER_PROMPT

def get_supervisor_prompt() -> str:
    """Get the supervisor prompt."""
    return SUPERVISOR_PROMPT
